import {
  select,
  scaleLinear,
  scaleOrdinal,
  extent,
  axisBottom,
  axisLeft,
  csv,
  schemePaired
} from 'd3';


import { dropdownMenu } from './dropdownMenu.js';
import { loadAndProcessData } from './loadAndProcessData';
import { colorLegend } from './colorLegend';
import { scatterPlot } from './scatterPlot';


const svg = select('svg');
const width = +svg.attr('width');
const height = +svg.attr('height');

const scatterPlotG = svg.append('g');
const colorLegendG = svg.append('g')
    .attr('transform',`translate(805,80)`);


const colorScale = scaleOrdinal(schemePaired);
const colorValue = d => d.pollutant;


const circleRadius = 10;
  
const margin = { top: 60, right: 130, bottom: 88, left: 130 };
const innerWidth = width - margin.left - margin.right - 50;
const innerHeight = height - margin.top - margin.bottom;

let data;
let selectedColorValue;
let xColumn;
let yColumn;


const onClick = d => {
  selectedColorValue = d;
  render();
}

loadAndProcessData()
  .then(d => {
    data = d;
    xColumn = d.columns[0];
    yColumn = d.columns[2];
    render();
});

const onXColumnClicked = column => {
  xColumn = column;
  render();
};

const onYColumnClicked = column => {
  yColumn = column;
  render();
};

const render = () => {
  
  /*select('#x-menu')
    .call(dropdownMenu, {
      options: data.columns.filter(column =>
       // column !== 'Date' &&
        column !== 'Year' &&
        column != 'Month' 
      ),
      onOptionClicked: onXColumnClicked,
      selectedOption: xColumn
    });

  select('#y-menu')
    .call(dropdownMenu, {
      options: data.columns.filter(column =>
        //column !== 'Date' &&
        column !== 'Year' &&
        column != 'Month' 
      ),
      onOptionClicked: onYColumnClicked,
      selectedOption: yColumn
    });*/
  
 

 /* colorScale
    .domain(data.map(colorValue))
    .domain(colorScale.domain().sort().reverse())
    .range(schemeSpectral[colorScale.domain().length]); */

    scatterPlotG.call(scatterPlot,{
      data,
      colorValue,
      colorScale,
      selectedColorValue,
      width,
      height,
      margin,
      title: 'London Monthly Air Quality: Roadside Pollution',
      xValue: d => d[xColumn],
      xAxisLabel: xColumn,
      yValue: d => d[yColumn],
      yAxisLabel: yColumn, 
      circleRadius,
      innerWidth,
      innerHeight
      });

  colorLegendG.call(colorLegend,{
    colorScale,
    circleRadius: 9.5,
    spacing: 22,
    textOffset: 12,
    backgroundRectWidth:171,
    onClick,
    selectedColorValue
  });
};